@@ -55,34 +55,6 @@ import org.apache.commons.codec.language.bm.Rule.Phoneme;
  */
 public class PhoneticEngine {
 
-    private static final int DEFAULT_MAX_PHONEMES = 20;
-
-    private static final Map<NameType, Set<String>> NAME_PREFIXES = new EnumMap<>(NameType.class);
-
-    private final Lang lang;
-
-    private final NameType nameType;
-
-    private final RuleType ruleType;
-
-    private final boolean concat;
-
-    private final int maxPhonemes;
-
-    static {
-        NAME_PREFIXES.put(NameType.ASHKENAZI,
-                Collections.unmodifiableSet(
-                        new HashSet<>(Arrays.asList("bar", "ben", "da", "de", "van", "von"))));
-        NAME_PREFIXES.put(NameType.SEPHARDIC,
-                Collections.unmodifiableSet(
-                        new HashSet<>(Arrays.asList("al", "el", "da", "dal", "de", "del", "dela", "de la",
-                                                          "della", "des", "di", "do", "dos", "du", "van", "von"))));
-        NAME_PREFIXES.put(NameType.GENERIC,
-                Collections.unmodifiableSet(
-                        new HashSet<>(Arrays.asList("da", "dal", "de", "del", "dela", "de la", "della",
-                                                          "des", "di", "do", "dos", "du", "van", "von"))));
-    }
-
     /**
      * Utility for manipulating a set of phonemes as they are being built up. Not intended for use outside
      * this package, and probably not outside the {@link PhoneticEngine} class.
@@ -91,8 +63,6 @@ public class PhoneticEngine {
      */
     static final class PhonemeBuilder {
 
-        private final Set<Rule.Phoneme> phonemes;
-
         /**
          * An empty builder where all phonemes must come from some set of languages. This will contain a single
          * phoneme of zero characters. This can then be appended to. This should be the only way to create a new
@@ -105,6 +75,8 @@ public class PhoneticEngine {
             return new PhonemeBuilder(new Rule.Phoneme("", languages));
         }
 
+        private final Set<Rule.Phoneme> phonemes;
+
         private PhonemeBuilder(final Rule.Phoneme phoneme) {
             this.phonemes = new LinkedHashSet<>();
             this.phonemes.add(phoneme);
@@ -134,9 +106,8 @@ public class PhoneticEngine {
          * @param maxPhonemes   the maximum number of phonemes to build up
          */
         public void apply(final Rule.PhonemeExpr phonemeExpr, final int maxPhonemes) {
-            final Set<Rule.Phoneme> newPhonemes = new LinkedHashSet<>(maxPhonemes);
-
-            EXPR: for (final Rule.Phoneme left : this.phonemes) {
+            final Set<Rule.Phoneme> newPhonemes = new LinkedHashSet<>(Math.min(phonemes.size() * phonemeExpr.size(), maxPhonemes));
+            EXPR: for (final Rule.Phoneme left : phonemes) {
                 for (final Rule.Phoneme right : phonemeExpr.getPhonemes()) {
                     final LanguageSet languages = left.getLanguages().restrictTo(right.getLanguages());
                     if (!languages.isEmpty()) {
@@ -150,9 +121,8 @@ public class PhoneticEngine {
                     }
                 }
             }
-
-            this.phonemes.clear();
-            this.phonemes.addAll(newPhonemes);
+            phonemes.clear();
+            phonemes.addAll(newPhonemes);
         }
 
         /**
@@ -161,7 +131,7 @@ public class PhoneticEngine {
          * @return  the phoneme set
          */
         public Set<Rule.Phoneme> getPhonemes() {
-            return this.phonemes;
+            return phonemes;
         }
 
         /**
@@ -183,22 +153,24 @@ public class PhoneticEngine {
      * processed already), and {@code found} indicates if a matching rule was found or not. In the case where a
      * matching rule was found, {@code phonemeBuilder} is replaced with a new builder containing the phonemes
      * updated by the matching rule.
-     *
+     * <p>
      * Although this class is not thread-safe (it has mutable unprotected fields), it is not shared between threads
      * as it is constructed as needed by the calling methods.
+     * </p>
+     *
      * @since 1.6
      */
     private static final class RulesApplication {
+
         private final Map<String, List<Rule>> finalRules;
         private final CharSequence input;
-
         private final PhonemeBuilder phonemeBuilder;
         private int i;
         private final int maxPhonemes;
         private boolean found;
 
-        public RulesApplication(final Map<String, List<Rule>> finalRules, final CharSequence input,
-                                final PhonemeBuilder phonemeBuilder, final int i, final int maxPhonemes) {
+        public RulesApplication(final Map<String, List<Rule>> finalRules, final CharSequence input, final PhonemeBuilder phonemeBuilder, final int i,
+                final int maxPhonemes) {
             Objects.requireNonNull(finalRules, "finalRules");
             this.finalRules = finalRules;
             this.phonemeBuilder = phonemeBuilder;
@@ -208,11 +180,11 @@ public class PhoneticEngine {
         }
 
         public int getI() {
-            return this.i;
+            return i;
         }
 
         public PhonemeBuilder getPhonemeBuilder() {
-            return this.phonemeBuilder;
+            return phonemeBuilder;
         }
 
         /**
@@ -223,34 +195,52 @@ public class PhoneticEngine {
          * @return {@code this}
          */
         public RulesApplication invoke() {
-            this.found = false;
+            found = false;
             int patternLength = 1;
-            final List<Rule> rules = this.finalRules.get(input.subSequence(i, i+patternLength));
+            final List<Rule> rules = finalRules.get(input.subSequence(i, i + patternLength));
             if (rules != null) {
                 for (final Rule rule : rules) {
                     final String pattern = rule.getPattern();
                     patternLength = pattern.length();
-                    if (rule.patternAndContextMatches(this.input, this.i)) {
-                        this.phonemeBuilder.apply(rule.getPhoneme(), maxPhonemes);
-                        this.found = true;
+                    if (rule.patternAndContextMatches(input, i)) {
+                        phonemeBuilder.apply(rule.getPhoneme(), maxPhonemes);
+                        found = true;
                         break;
                     }
                 }
             }
 
-            if (!this.found) {
+            if (!found) {
                 patternLength = 1;
             }
 
-            this.i += patternLength;
+            i += patternLength;
             return this;
         }
 
         public boolean isFound() {
-            return this.found;
+            return found;
         }
     }
 
+    private static final int DEFAULT_MAX_PHONEMES = 20;
+
+    private static final Map<NameType, Set<String>> NAME_PREFIXES = new EnumMap<>(NameType.class);
+
+    static {
+        NAME_PREFIXES.put(NameType.ASHKENAZI,
+                Collections.unmodifiableSet(
+                        new HashSet<>(Arrays.asList("bar", "ben", "da", "de", "van", "von"))));
+        NAME_PREFIXES.put(NameType.SEPHARDIC,
+                Collections.unmodifiableSet(
+                        new HashSet<>(Arrays.asList("al", "el", "da", "dal", "de", "del", "dela", "de la",
+                                                          "della", "des", "di", "do", "dos", "du", "van", "von"))));
+        NAME_PREFIXES.put(NameType.GENERIC,
+                Collections.unmodifiableSet(
+                        new HashSet<>(Arrays.asList("da", "dal", "de", "del", "dela", "de la", "della",
+                                                          "des", "di", "do", "dos", "du", "van", "von"))));
+    }
+
     /**
      * Joins some strings with an internal separator.
      *
@@ -262,6 +252,16 @@ public class PhoneticEngine {
         return strings.stream().collect(Collectors.joining(sep));
     }
 
+    private final Lang lang;
+
+    private final NameType nameType;
+
+    private final RuleType ruleType;
+
+    private final boolean concat;
+
+    private final int maxPhonemes;
+
     /**
      * Generates a new, fully-configured phonetic engine.
      *
@@ -269,11 +269,11 @@ public class PhoneticEngine {
      *            the type of names it will use
      * @param ruleType
      *            the type of rules it will apply
-     * @param concat
+     * @param concatenate
      *            if it will concatenate multiple encodings
      */
-    public PhoneticEngine(final NameType nameType, final RuleType ruleType, final boolean concat) {
-        this(nameType, ruleType, concat, DEFAULT_MAX_PHONEMES);
+    public PhoneticEngine(final NameType nameType, final RuleType ruleType, final boolean concatenate) {
+        this(nameType, ruleType, concatenate, DEFAULT_MAX_PHONEMES);
     }
 
     /**
@@ -283,20 +283,19 @@ public class PhoneticEngine {
      *            the type of names it will use
      * @param ruleType
      *            the type of rules it will apply
-     * @param concat
+     * @param concatenate
      *            if it will concatenate multiple encodings
      * @param maxPhonemes
      *            the maximum number of phonemes that will be handled
      * @since 1.7
      */
-    public PhoneticEngine(final NameType nameType, final RuleType ruleType, final boolean concat,
-                          final int maxPhonemes) {
+    public PhoneticEngine(final NameType nameType, final RuleType ruleType, final boolean concatenate, final int maxPhonemes) {
         if (ruleType == RuleType.RULES) {
             throw new IllegalArgumentException("ruleType must not be " + RuleType.RULES);
         }
         this.nameType = nameType;
         this.ruleType = ruleType;
-        this.concat = concat;
+        this.concat = concatenate;
         this.lang = Lang.instance(nameType);
         this.maxPhonemes = maxPhonemes;
     }
@@ -409,7 +408,7 @@ public class PhoneticEngine {
         switch (this.nameType) {
         case SEPHARDIC:
             words.forEach(aWord -> {
-                final String[] parts = aWord.split("'");
+                final String[] parts = aWord.split("'", -1);
                 words2.add(parts[parts.length - 1]);
             });
             words2.removeAll(NAME_PREFIXES.get(this.nameType));
@@ -431,7 +430,7 @@ public class PhoneticEngine {
         } else if (words2.size() == 1) {
             // not a multi-word name
             input = words.iterator().next();
-        } else {
+        } else if (!words2.isEmpty()) {
             // encode each word in a multi-word name separately (normally used for approx matches)
             final StringBuilder result = new StringBuilder();
             words2.forEach(word -> result.append("-").append(encode(word)));
@@ -466,6 +465,16 @@ public class PhoneticEngine {
         return this.lang;
     }
 
+    /**
+     * Gets the maximum number of phonemes the engine will calculate for a given input.
+     *
+     * @return the maximum number of phonemes
+     * @since 1.7
+     */
+    public int getMaxPhonemes() {
+        return this.maxPhonemes;
+    }
+
     /**
      * Gets the NameType being used.
      *
@@ -492,14 +501,4 @@ public class PhoneticEngine {
     public boolean isConcat() {
         return this.concat;
     }
-
-    /**
-     * Gets the maximum number of phonemes the engine will calculate for a given input.
-     *
-     * @return the maximum number of phonemes
-     * @since 1.7
-     */
-    public int getMaxPhonemes() {
-        return this.maxPhonemes;
-    }
 }
