@@ -69,16 +69,6 @@ import org.apache.commons.codec.binary.StringUtils;
  * @since 1.3
  */
 public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, StringEncoder, StringDecoder {
-    /**
-     * The default Charset used for string decoding and encoding.
-     */
-    private final Charset charset;
-
-    /**
-     * Indicates whether soft line breaks shall be used during encoding (rule #3-5).
-     */
-    private final boolean strict;
-
     /**
      * BitSet of printable characters as defined in RFC 1521.
      */
@@ -94,6 +84,11 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
 
     private static final byte LF = 10;
 
+    /**
+     * Minimum length required for the byte arrays used by encodeQuotedPrintable method
+     */
+    private static final int MIN_BYTES = 3;
+
     /**
      * Safe line length for quoted printable encoded text.
      */
@@ -112,6 +107,228 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
         PRINTABLE_CHARS.set(SPACE);
     }
 
+    /**
+     * Decodes an array quoted-printable characters into an array of original bytes. Escaped characters are converted
+     * back to their original representation.
+     * <p>
+     * This function fully implements the quoted-printable encoding specification (rule #1 through rule #5) as
+     * defined in RFC 1521.
+     * </p>
+     *
+     * @param bytes
+     *            array of quoted-printable characters
+     * @return array of original bytes
+     * @throws DecoderException
+     *             Thrown if quoted-printable decoding is unsuccessful
+     */
+    public static final byte[] decodeQuotedPrintable(final byte[] bytes) throws DecoderException {
+        if (bytes == null) {
+            return null;
+        }
+        final ByteArrayOutputStream buffer = new ByteArrayOutputStream();
+        for (int i = 0; i < bytes.length; i++) {
+            final int b = bytes[i];
+            if (b == ESCAPE_CHAR) {
+                try {
+                    // if the next octet is a CR we have found a soft line break
+                    if (bytes[++i] == CR) {
+                        continue;
+                    }
+                    final int u = Utils.digit16(bytes[i]);
+                    final int l = Utils.digit16(bytes[++i]);
+                    buffer.write((char) ((u << 4) + l));
+                } catch (final ArrayIndexOutOfBoundsException e) {
+                    throw new DecoderException("Invalid quoted-printable encoding", e);
+                }
+            } else if (b != CR && b != LF) {
+                // every other octet is appended except for CR & LF
+                buffer.write(b);
+            }
+        }
+        return buffer.toByteArray();
+    }
+
+    /**
+     * Encodes a byte in the buffer.
+     *
+     * @param b
+     *            byte to write
+     * @param encode
+     *            indicates whether the octet shall be encoded
+     * @param buffer
+     *            the buffer to write to
+     * @return the number of bytes that have been written to the buffer
+     */
+    private static int encodeByte(final int b, final boolean encode, final ByteArrayOutputStream buffer) {
+        if (encode) {
+            return encodeQuotedPrintable(b, buffer);
+        }
+        buffer.write(b);
+        return 1;
+    }
+
+    /**
+     * Encodes an array of bytes into an array of quoted-printable 7-bit characters. Unsafe characters are escaped.
+     * <p>
+     * This function implements a subset of quoted-printable encoding specification (rule #1 and rule #2) as defined in
+     * RFC 1521 and is suitable for encoding binary data and unformatted text.
+     * </p>
+     *
+     * @param printable
+     *            bitset of characters deemed quoted-printable
+     * @param bytes
+     *            array of bytes to be encoded
+     * @return array of bytes containing quoted-printable data
+     */
+    public static final byte[] encodeQuotedPrintable(final BitSet printable, final byte[] bytes) {
+        return encodeQuotedPrintable(printable, bytes, false);
+    }
+
+    /**
+     * Encodes an array of bytes into an array of quoted-printable 7-bit characters. Unsafe characters are escaped.
+     * <p>
+     * Depending on the selection of the {@code strict} parameter, this function either implements the full ruleset
+     * or only a subset of quoted-printable encoding specification (rule #1 and rule #2) as defined in
+     * RFC 1521 and is suitable for encoding binary data and unformatted text.
+     * </p>
+     *
+     * @param printable
+     *            bitset of characters deemed quoted-printable
+     * @param bytes
+     *            array of bytes to be encoded
+     * @param strict
+     *            if {@code true} the full ruleset is used, otherwise only rule #1 and rule #2
+     * @return array of bytes containing quoted-printable data
+     * @since 1.10
+     */
+    public static final byte[] encodeQuotedPrintable(BitSet printable, final byte[] bytes, final boolean strict) {
+        if (bytes == null) {
+            return null;
+        }
+        if (printable == null) {
+            printable = PRINTABLE_CHARS;
+        }
+        final ByteArrayOutputStream buffer = new ByteArrayOutputStream();
+        final int bytesLength = bytes.length;
+
+        if (strict) {
+            if (bytesLength < MIN_BYTES) {
+                return null;
+            }
+
+            int pos = 1;
+            // encode up to buffer.length - 3, the last three octets will be treated
+            // separately for simplification of note #3
+            for (int i = 0; i < bytesLength - 3; i++) {
+                final int b = getUnsignedOctet(i, bytes);
+                if (pos < SAFE_LENGTH) {
+                    // up to this length it is safe to add any byte, encoded or not
+                    pos += encodeByte(b, !printable.get(b), buffer);
+                } else {
+                    // rule #3: whitespace at the end of a line *must* be encoded
+                    encodeByte(b, !printable.get(b) || isWhitespace(b), buffer);
+
+                    // rule #5: soft line break
+                    buffer.write(ESCAPE_CHAR);
+                    buffer.write(CR);
+                    buffer.write(LF);
+                    pos = 1;
+                }
+            }
+
+            // rule #3: whitespace at the end of a line *must* be encoded
+            // if we would do a soft break line after this octet, encode whitespace
+            int b = getUnsignedOctet(bytesLength - 3, bytes);
+            boolean encode = !printable.get(b) || isWhitespace(b) && pos > SAFE_LENGTH - 5;
+            pos += encodeByte(b, encode, buffer);
+
+            // note #3: '=' *must not* be the ultimate or penultimate character
+            // simplification: if < 6 bytes left, do a soft line break as we may need
+            //                 exactly 6 bytes space for the last 2 bytes
+            if (pos > SAFE_LENGTH - 2) {
+                buffer.write(ESCAPE_CHAR);
+                buffer.write(CR);
+                buffer.write(LF);
+            }
+            for (int i = bytesLength - 2; i < bytesLength; i++) {
+                b = getUnsignedOctet(i, bytes);
+                // rule #3: trailing whitespace shall be encoded
+                encode = !printable.get(b) || i > bytesLength - 2 && isWhitespace(b);
+                encodeByte(b, encode, buffer);
+            }
+        } else {
+            for (final byte c : bytes) {
+                int b = c;
+                if (b < 0) {
+                    b = 256 + b;
+                }
+                if (printable.get(b)) {
+                    buffer.write(b);
+                } else {
+                    encodeQuotedPrintable(b, buffer);
+                }
+            }
+        }
+        return buffer.toByteArray();
+    }
+
+    /**
+     * Encodes byte into its quoted-printable representation.
+     *
+     * @param b
+     *            byte to encode
+     * @param buffer
+     *            the buffer to write to
+     * @return The number of bytes written to the {@code buffer}
+     */
+    private static final int encodeQuotedPrintable(final int b, final ByteArrayOutputStream buffer) {
+        buffer.write(ESCAPE_CHAR);
+        final char hex1 = Utils.hexDigit(b >> 4);
+        final char hex2 = Utils.hexDigit(b);
+        buffer.write(hex1);
+        buffer.write(hex2);
+        return 3;
+    }
+
+    /**
+     * Gets the byte at position {@code index} of the byte array and
+     * make sure it is unsigned.
+     *
+     * @param index
+     *            position in the array
+     * @param bytes
+     *            the byte array
+     * @return the unsigned octet at position {@code index} from the array
+     */
+    private static int getUnsignedOctet(final int index, final byte[] bytes) {
+        int b = bytes[index];
+        if (b < 0) {
+            b = 256 + b;
+        }
+        return b;
+    }
+
+    /**
+     * Checks whether the given byte is whitespace.
+     *
+     * @param b
+     *            byte to be checked
+     * @return {@code true} if the byte is either a space or tab character
+     */
+    private static boolean isWhitespace(final int b) {
+        return b == SPACE || b == TAB;
+    }
+
+    /**
+     * The default Charset used for string decoding and encoding.
+     */
+    private final Charset charset;
+
+    /**
+     * Indicates whether soft line breaks shall be used during encoding (rule #3-5).
+     */
+    private final boolean strict;
+
     /**
      * Default constructor, assumes default Charset of {@link StandardCharsets#UTF_8}
      */
@@ -170,238 +387,17 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
      *
      * @since 1.7 throws UnsupportedCharsetException if the named Charset is unavailable
      */
-    public QuotedPrintableCodec(final String charsetName)
-            throws IllegalCharsetNameException, IllegalArgumentException, UnsupportedCharsetException {
+    public QuotedPrintableCodec(final String charsetName) throws IllegalCharsetNameException, IllegalArgumentException, UnsupportedCharsetException {
         this(Charset.forName(charsetName), false);
     }
 
-    /**
-     * Encodes byte into its quoted-printable representation.
-     *
-     * @param b
-     *            byte to encode
-     * @param buffer
-     *            the buffer to write to
-     * @return The number of bytes written to the {@code buffer}
-     */
-    private static final int encodeQuotedPrintable(final int b, final ByteArrayOutputStream buffer) {
-        buffer.write(ESCAPE_CHAR);
-        final char hex1 = Utils.hexDigit(b >> 4);
-        final char hex2 = Utils.hexDigit(b);
-        buffer.write(hex1);
-        buffer.write(hex2);
-        return 3;
-    }
-
-    /**
-     * Return the byte at position {@code index} of the byte array and
-     * make sure it is unsigned.
-     *
-     * @param index
-     *            position in the array
-     * @param bytes
-     *            the byte array
-     * @return the unsigned octet at position {@code index} from the array
-     */
-    private static int getUnsignedOctet(final int index, final byte[] bytes) {
-        int b = bytes[index];
-        if (b < 0) {
-            b = 256 + b;
-        }
-        return b;
-    }
-
-    /**
-     * Write a byte to the buffer.
-     *
-     * @param b
-     *            byte to write
-     * @param encode
-     *            indicates whether the octet shall be encoded
-     * @param buffer
-     *            the buffer to write to
-     * @return the number of bytes that have been written to the buffer
-     */
-    private static int encodeByte(final int b, final boolean encode,
-                                  final ByteArrayOutputStream buffer) {
-        if (encode) {
-            return encodeQuotedPrintable(b, buffer);
-        }
-        buffer.write(b);
-        return 1;
-    }
-
-    /**
-     * Checks whether the given byte is whitespace.
-     *
-     * @param b
-     *            byte to be checked
-     * @return {@code true} if the byte is either a space or tab character
-     */
-    private static boolean isWhitespace(final int b) {
-        return b == SPACE || b == TAB;
-    }
-
-    /**
-     * Encodes an array of bytes into an array of quoted-printable 7-bit characters. Unsafe characters are escaped.
-     * <p>
-     * This function implements a subset of quoted-printable encoding specification (rule #1 and rule #2) as defined in
-     * RFC 1521 and is suitable for encoding binary data and unformatted text.
-     *
-     * @param printable
-     *            bitset of characters deemed quoted-printable
-     * @param bytes
-     *            array of bytes to be encoded
-     * @return array of bytes containing quoted-printable data
-     */
-    public static final byte[] encodeQuotedPrintable(final BitSet printable, final byte[] bytes) {
-        return encodeQuotedPrintable(printable, bytes, false);
-    }
-
-    /**
-     * Encodes an array of bytes into an array of quoted-printable 7-bit characters. Unsafe characters are escaped.
-     * <p>
-     * Depending on the selection of the {@code strict} parameter, this function either implements the full ruleset
-     * or only a subset of quoted-printable encoding specification (rule #1 and rule #2) as defined in
-     * RFC 1521 and is suitable for encoding binary data and unformatted text.
-     *
-     * @param printable
-     *            bitset of characters deemed quoted-printable
-     * @param bytes
-     *            array of bytes to be encoded
-     * @param strict
-     *            if {@code true} the full ruleset is used, otherwise only rule #1 and rule #2
-     * @return array of bytes containing quoted-printable data
-     * @since 1.10
-     */
-    public static final byte[] encodeQuotedPrintable(BitSet printable, final byte[] bytes, final boolean strict) {
-        if (bytes == null) {
-            return null;
-        }
-        if (printable == null) {
-            printable = PRINTABLE_CHARS;
-        }
-        final ByteArrayOutputStream buffer = new ByteArrayOutputStream();
-
-        if (strict) {
-            int pos = 1;
-            // encode up to buffer.length - 3, the last three octets will be treated
-            // separately for simplification of note #3
-            for (int i = 0; i < bytes.length - 3; i++) {
-                final int b = getUnsignedOctet(i, bytes);
-                if (pos < SAFE_LENGTH) {
-                    // up to this length it is safe to add any byte, encoded or not
-                    pos += encodeByte(b, !printable.get(b), buffer);
-                } else {
-                    // rule #3: whitespace at the end of a line *must* be encoded
-                    encodeByte(b, !printable.get(b) || isWhitespace(b), buffer);
-
-                    // rule #5: soft line break
-                    buffer.write(ESCAPE_CHAR);
-                    buffer.write(CR);
-                    buffer.write(LF);
-                    pos = 1;
-                }
-            }
-
-            // rule #3: whitespace at the end of a line *must* be encoded
-            // if we would do a soft break line after this octet, encode whitespace
-            int b = getUnsignedOctet(bytes.length - 3, bytes);
-            boolean encode = !printable.get(b) || (isWhitespace(b) && pos > SAFE_LENGTH - 5);
-            pos += encodeByte(b, encode, buffer);
-
-            // note #3: '=' *must not* be the ultimate or penultimate character
-            // simplification: if < 6 bytes left, do a soft line break as we may need
-            //                 exactly 6 bytes space for the last 2 bytes
-            if (pos > SAFE_LENGTH - 2) {
-                buffer.write(ESCAPE_CHAR);
-                buffer.write(CR);
-                buffer.write(LF);
-            }
-            for (int i = bytes.length - 2; i < bytes.length; i++) {
-                b = getUnsignedOctet(i, bytes);
-                // rule #3: trailing whitespace shall be encoded
-                encode = !printable.get(b) || (i > bytes.length - 2 && isWhitespace(b));
-                encodeByte(b, encode, buffer);
-            }
-        } else {
-            for (final byte c : bytes) {
-                int b = c;
-                if (b < 0) {
-                    b = 256 + b;
-                }
-                if (printable.get(b)) {
-                    buffer.write(b);
-                } else {
-                    encodeQuotedPrintable(b, buffer);
-                }
-            }
-        }
-        return buffer.toByteArray();
-    }
-
-    /**
-     * Decodes an array quoted-printable characters into an array of original bytes. Escaped characters are converted
-     * back to their original representation.
-     * <p>
-     * This function fully implements the quoted-printable encoding specification (rule #1 through rule #5) as
-     * defined in RFC 1521.
-     *
-     * @param bytes
-     *            array of quoted-printable characters
-     * @return array of original bytes
-     * @throws DecoderException
-     *             Thrown if quoted-printable decoding is unsuccessful
-     */
-    public static final byte[] decodeQuotedPrintable(final byte[] bytes) throws DecoderException {
-        if (bytes == null) {
-            return null;
-        }
-        final ByteArrayOutputStream buffer = new ByteArrayOutputStream();
-        for (int i = 0; i < bytes.length; i++) {
-            final int b = bytes[i];
-            if (b == ESCAPE_CHAR) {
-                try {
-                    // if the next octet is a CR we have found a soft line break
-                    if (bytes[++i] == CR) {
-                        continue;
-                    }
-                    final int u = Utils.digit16(bytes[i]);
-                    final int l = Utils.digit16(bytes[++i]);
-                    buffer.write((char) ((u << 4) + l));
-                } catch (final ArrayIndexOutOfBoundsException e) {
-                    throw new DecoderException("Invalid quoted-printable encoding", e);
-                }
-            } else if (b != CR && b != LF) {
-                // every other octet is appended except for CR & LF
-                buffer.write(b);
-            }
-        }
-        return buffer.toByteArray();
-    }
-
-    /**
-     * Encodes an array of bytes into an array of quoted-printable 7-bit characters. Unsafe characters are escaped.
-     * <p>
-     * Depending on the selection of the {@code strict} parameter, this function either implements the full ruleset
-     * or only a subset of quoted-printable encoding specification (rule #1 and rule #2) as defined in
-     * RFC 1521 and is suitable for encoding binary data and unformatted text.
-     *
-     * @param bytes
-     *            array of bytes to be encoded
-     * @return array of bytes containing quoted-printable data
-     */
-    @Override
-    public byte[] encode(final byte[] bytes) {
-        return encodeQuotedPrintable(PRINTABLE_CHARS, bytes, strict);
-    }
-
     /**
      * Decodes an array of quoted-printable characters into an array of original bytes. Escaped characters are converted
      * back to their original representation.
      * <p>
      * This function fully implements the quoted-printable encoding specification (rule #1 through rule #5) as
      * defined in RFC 1521.
+     * </p>
      *
      * @param bytes
      *            array of quoted-printable characters
@@ -415,23 +411,44 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
     }
 
     /**
-     * Encodes a string into its quoted-printable form using the default string Charset. Unsafe characters are escaped.
-     * <p>
-     * Depending on the selection of the {@code strict} parameter, this function either implements the full ruleset
-     * or only a subset of quoted-printable encoding specification (rule #1 and rule #2) as defined in
-     * RFC 1521 and is suitable for encoding binary data and unformatted text.
+     * Decodes a quoted-printable object into its original form. Escaped characters are converted back to their original
+     * representation.
+     *
+     * @param obj
+     *            quoted-printable object to convert into its original form
+     * @return original object
+     * @throws DecoderException
+     *             Thrown if the argument is not a {@code String} or {@code byte[]}. Thrown if a failure
+     *             condition is encountered during the decode process.
+     */
+    @Override
+    public Object decode(final Object obj) throws DecoderException {
+        if (obj == null) {
+            return null;
+        }
+        if (obj instanceof byte[]) {
+            return decode((byte[]) obj);
+        }
+        if (obj instanceof String) {
+            return decode((String) obj);
+        }
+        throw new DecoderException("Objects of type " + obj.getClass().getName() + " cannot be quoted-printable decoded");
+    }
+
+    /**
+     * Decodes a quoted-printable string into its original form using the default string Charset. Escaped characters are
+     * converted back to their original representation.
      *
      * @param sourceStr
-     *            string to convert to quoted-printable form
-     * @return quoted-printable string
-     * @throws EncoderException
-     *             Thrown if quoted-printable encoding is unsuccessful
-     *
+     *            quoted-printable string to convert into its original form
+     * @return original string
+     * @throws DecoderException
+     *             Thrown if quoted-printable decoding is unsuccessful. Thrown if Charset is not supported.
      * @see #getCharset()
      */
     @Override
-    public String encode(final String sourceStr) throws EncoderException {
-        return this.encode(sourceStr, getCharset());
+    public String decode(final String sourceStr) throws DecoderException {
+        return this.decode(sourceStr, getCharset());
     }
 
     /**
@@ -468,8 +485,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
      * @throws UnsupportedEncodingException
      *             Thrown if Charset is not supported
      */
-    public String decode(final String sourceStr, final String sourceCharset)
-            throws DecoderException, UnsupportedEncodingException {
+    public String decode(final String sourceStr, final String sourceCharset) throws DecoderException, UnsupportedEncodingException {
         if (sourceStr == null) {
             return null;
         }
@@ -477,19 +493,20 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
     }
 
     /**
-     * Decodes a quoted-printable string into its original form using the default string Charset. Escaped characters are
-     * converted back to their original representation.
+     * Encodes an array of bytes into an array of quoted-printable 7-bit characters. Unsafe characters are escaped.
+     * <p>
+     * Depending on the selection of the {@code strict} parameter, this function either implements the full ruleset
+     * or only a subset of quoted-printable encoding specification (rule #1 and rule #2) as defined in
+     * RFC 1521 and is suitable for encoding binary data and unformatted text.
+     * </p>
      *
-     * @param sourceStr
-     *            quoted-printable string to convert into its original form
-     * @return original string
-     * @throws DecoderException
-     *             Thrown if quoted-printable decoding is unsuccessful. Thrown if Charset is not supported.
-     * @see #getCharset()
+     * @param bytes
+     *            array of bytes to be encoded
+     * @return array of bytes containing quoted-printable data
      */
     @Override
-    public String decode(final String sourceStr) throws DecoderException {
-        return this.decode(sourceStr, this.getCharset());
+    public byte[] encode(final byte[] bytes) {
+        return encodeQuotedPrintable(PRINTABLE_CHARS, bytes, strict);
     }
 
     /**
@@ -506,60 +523,35 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
     public Object encode(final Object obj) throws EncoderException {
         if (obj == null) {
             return null;
-        } else if (obj instanceof byte[]) {
-            return encode((byte[]) obj);
-        } else if (obj instanceof String) {
-            return encode((String) obj);
-        } else {
-            throw new EncoderException("Objects of type " +
-                  obj.getClass().getName() +
-                  " cannot be quoted-printable encoded");
         }
+        if (obj instanceof byte[]) {
+            return encode((byte[]) obj);
+        }
+        if (obj instanceof String) {
+            return encode((String) obj);
+        }
+        throw new EncoderException("Objects of type " + obj.getClass().getName() + " cannot be quoted-printable encoded");
     }
 
     /**
-     * Decodes a quoted-printable object into its original form. Escaped characters are converted back to their original
-     * representation.
+     * Encodes a string into its quoted-printable form using the default string Charset. Unsafe characters are escaped.
+     * <p>
+     * Depending on the selection of the {@code strict} parameter, this function either implements the full ruleset
+     * or only a subset of quoted-printable encoding specification (rule #1 and rule #2) as defined in
+     * RFC 1521 and is suitable for encoding binary data and unformatted text.
+     * </p>
      *
-     * @param obj
-     *            quoted-printable object to convert into its original form
-     * @return original object
-     * @throws DecoderException
-     *             Thrown if the argument is not a {@code String} or {@code byte[]}. Thrown if a failure
-     *             condition is encountered during the decode process.
+     * @param sourceStr
+     *            string to convert to quoted-printable form
+     * @return quoted-printable string
+     * @throws EncoderException
+     *             Thrown if quoted-printable encoding is unsuccessful
+     *
+     * @see #getCharset()
      */
     @Override
-    public Object decode(final Object obj) throws DecoderException {
-        if (obj == null) {
-            return null;
-        } else if (obj instanceof byte[]) {
-            return decode((byte[]) obj);
-        } else if (obj instanceof String) {
-            return decode((String) obj);
-        } else {
-            throw new DecoderException("Objects of type " +
-                  obj.getClass().getName() +
-                  " cannot be quoted-printable decoded");
-        }
-    }
-
-    /**
-     * Gets the default Charset name used for string decoding and encoding.
-     *
-     * @return the default Charset name
-     * @since 1.7
-     */
-    public Charset getCharset() {
-        return this.charset;
-    }
-
-    /**
-     * Gets the default Charset name used for string decoding and encoding.
-     *
-     * @return the default Charset name
-     */
-    public String getDefaultCharset() {
-        return this.charset.name();
+    public String encode(final String sourceStr) throws EncoderException {
+        return encode(sourceStr, getCharset());
     }
 
     /**
@@ -568,6 +560,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
      * Depending on the selection of the {@code strict} parameter, this function either implements the full ruleset
      * or only a subset of quoted-printable encoding specification (rule #1 and rule #2) as defined in
      * RFC 1521 and is suitable for encoding binary data and unformatted text.
+     * </p>
      *
      * @param sourceStr
      *            string to convert to quoted-printable form
@@ -589,6 +582,7 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
      * Depending on the selection of the {@code strict} parameter, this function either implements the full ruleset
      * or only a subset of quoted-printable encoding specification (rule #1 and rule #2) as defined in
      * RFC 1521 and is suitable for encoding binary data and unformatted text.
+     * </p>
      *
      * @param sourceStr
      *            string to convert to quoted-printable form
@@ -604,4 +598,23 @@ public class QuotedPrintableCodec implements BinaryEncoder, BinaryDecoder, Strin
         }
         return StringUtils.newStringUsAscii(encode(sourceStr.getBytes(sourceCharset)));
     }
+
+    /**
+     * Gets the default Charset name used for string decoding and encoding.
+     *
+     * @return the default Charset name
+     * @since 1.7
+     */
+    public Charset getCharset() {
+        return this.charset;
+    }
+
+    /**
+     * Gets the default Charset name used for string decoding and encoding.
+     *
+     * @return the default Charset name
+     */
+    public String getDefaultCharset() {
+        return this.charset.name();
+    }
 }
