@@ -42,36 +42,30 @@ public class Base32InputStreamTest {
     private static final String STRING_FIXTURE = "Hello World";
 
     /**
-     * Tests the problem reported in CODEC-130. Missing / wrong implementation of skip.
+     * Tests skipping past the end of a stream.
+     *
+     * @throws Throwable
+     *             for some failure scenarios.
      */
     @Test
-    public void testCodec130() throws IOException {
-        final ByteArrayOutputStream bos = new ByteArrayOutputStream();
-        try (final Base32OutputStream base32os = new Base32OutputStream(bos)) {
-            base32os.write(StringUtils.getBytesUtf8(STRING_FIXTURE));
+    public void testAvailable() throws Throwable {
+        final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
+        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+            assertEquals(1, b32stream.available());
+            assertEquals(3, b32stream.skip(10));
+            // End of stream reached
+            assertEquals(0, b32stream.available());
+            assertEquals(-1, b32stream.read());
+            assertEquals(-1, b32stream.read());
+            assertEquals(0, b32stream.available());
         }
-
-        final ByteArrayInputStream bis = new ByteArrayInputStream(bos.toByteArray());
-        final Base32InputStream ins = new Base32InputStream(bis);
-
-        // we skip the first character read from the reader
-        ins.skip(1);
-        final byte[] decodedBytes = BaseNTestData.streamToBytes(ins, new byte[64]);
-        final String str = StringUtils.newStringUtf8(decodedBytes);
-
-        assertEquals(STRING_FIXTURE.substring(1), str);
     }
 
-    /**
-     * Tests the bug reported in CODEC-105. Bad interactions with InputStream when reading one byte at a time.
-     */
-    @Test
-    public void testCodec105() throws IOException {
-        try (final Base32InputStream in = new Base32InputStream(new Codec105ErrorInputStream(), true, 0, null)) {
-            for (int i = 0; i < 5; i++) {
-                in.read();
-            }
-        }
+    private void testBase32EmptyInputStream(final int chuckSize) throws Exception {
+        final byte[] emptyEncoded = {};
+        final byte[] emptyDecoded = {};
+        testByteByByte(emptyEncoded, emptyDecoded, chuckSize, CRLF);
+        testByChunk(emptyEncoded, emptyDecoded, chuckSize, CRLF);
     }
 
     // /**
@@ -140,26 +134,6 @@ public class Base32InputStreamTest {
     // );
     // }
 
-    /**
-     * Tests skipping past the end of a stream.
-     *
-     * @throws Throwable
-     *             for some failure scenarios.
-     */
-    @Test
-    public void testAvailable() throws Throwable {
-        final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
-            assertEquals(1, b32stream.available());
-            assertEquals(3, b32stream.skip(10));
-            // End of stream reached
-            assertEquals(0, b32stream.available());
-            assertEquals(-1, b32stream.read());
-            assertEquals(-1, b32stream.read());
-            assertEquals(0, b32stream.available());
-        }
-    }
-
     /**
      * Tests the Base32InputStream implementation against empty input.
      *
@@ -182,13 +156,6 @@ public class Base32InputStreamTest {
         testBase32EmptyInputStream(BaseNCodec.PEM_CHUNK_SIZE);
     }
 
-    private void testBase32EmptyInputStream(final int chuckSize) throws Exception {
-        final byte[] emptyEncoded = {};
-        final byte[] emptyDecoded = {};
-        testByteByByte(emptyEncoded, emptyDecoded, chuckSize, CRLF);
-        testByChunk(emptyEncoded, emptyDecoded, chuckSize, CRLF);
-    }
-
     /**
      * Tests the Base32InputStream implementation.
      *
@@ -281,33 +248,28 @@ public class Base32InputStreamTest {
      *             Usually signifies a bug in the Base32 commons-codec implementation.
      */
     private void testByChunk(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
-
         // Start with encode.
-        InputStream in;
-
-        in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator);
-        byte[] output = BaseNTestData.streamToBytes(in);
-
-        assertEquals(-1, in.read(), "EOF");
-        assertEquals(-1, in.read(), "Still EOF");
-        assertArrayEquals(encoded, output, "Streaming base32 encode");
-
+        try (InputStream in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator)) {
+            final byte[] output = BaseNTestData.streamToBytes(in);
+            assertEquals(-1, in.read(), "EOF");
+            assertEquals(-1, in.read(), "Still EOF");
+            assertArrayEquals(encoded, output, "Streaming base32 encode");
+        }
         // Now let's try to decode.
-        in = new Base32InputStream(new ByteArrayInputStream(encoded));
-        output = BaseNTestData.streamToBytes(in);
-
-        assertEquals(-1, in.read(), "EOF");
-        assertEquals(-1, in.read(), "Still EOF");
-        assertArrayEquals(decoded, output, "Streaming base32 decode");
+        try (InputStream in = new Base32InputStream(new ByteArrayInputStream(encoded))) {
+            final byte[] output = BaseNTestData.streamToBytes(in);
 
+            assertEquals(-1, in.read(), "EOF");
+            assertEquals(-1, in.read(), "Still EOF");
+            assertArrayEquals(decoded, output, "Streaming base32 decode");
+        }
         // I always wanted to do this! (wrap encoder with decoder etc.).
-        in = new ByteArrayInputStream(decoded);
+        InputStream in = new ByteArrayInputStream(decoded);
         for (int i = 0; i < 10; i++) {
             in = new Base32InputStream(in, true, chunkSize, separator);
             in = new Base32InputStream(in, false);
         }
-        output = BaseNTestData.streamToBytes(in);
-
+        final byte[] output = BaseNTestData.streamToBytes(in);
         assertEquals(-1, in.read(), "EOF");
         assertEquals(-1, in.read(), "Still EOF");
         assertArrayEquals(decoded, output, "Streaming base32 wrap-wrap-wrap!");
@@ -377,6 +339,39 @@ public class Base32InputStreamTest {
         assertArrayEquals(decoded, output, "Streaming base32 wrap-wrap-wrap!");
     }
 
+    /**
+     * Tests the bug reported in CODEC-105. Bad interactions with InputStream when reading one byte at a time.
+     */
+    @Test
+    public void testCodec105() throws IOException {
+        try (final Base32InputStream in = new Base32InputStream(new Codec105ErrorInputStream(), true, 0, null)) {
+            for (int i = 0; i < 5; i++) {
+                in.read();
+            }
+        }
+    }
+
+    /**
+     * Tests the problem reported in CODEC-130. Missing / wrong implementation of skip.
+     */
+    @Test
+    public void testCodec130() throws IOException {
+        final ByteArrayOutputStream bos = new ByteArrayOutputStream();
+        try (final Base32OutputStream base32os = new Base32OutputStream(bos)) {
+            base32os.write(StringUtils.getBytesUtf8(STRING_FIXTURE));
+        }
+
+        final ByteArrayInputStream bis = new ByteArrayInputStream(bos.toByteArray());
+        final Base32InputStream ins = new Base32InputStream(bis);
+
+        // we skip the first character read from the reader
+        ins.skip(1);
+        final byte[] decodedBytes = BaseNTestData.streamToBytes(ins, new byte[64]);
+        final String str = StringUtils.newStringUtf8(decodedBytes);
+
+        assertEquals(STRING_FIXTURE.substring(1), str);
+    }
+
     /**
      * Tests markSupported.
      *
@@ -445,6 +440,23 @@ public class Base32InputStreamTest {
         }
     }
 
+    /**
+     * Tests skipping number of characters larger than the internal buffer.
+     *
+     * @throws Throwable
+     *             for some failure scenarios.
+     */
+    @Test
+    public void testSkipBig() throws Throwable {
+        final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
+        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+            assertEquals(3, b32stream.skip(1024));
+            // End of stream reached
+            assertEquals(-1, b32stream.read());
+            assertEquals(-1, b32stream.read());
+        }
+    }
+
     /**
      * Tests skipping as a noop
      *
@@ -464,23 +476,6 @@ public class Base32InputStreamTest {
         }
     }
 
-    /**
-     * Tests skipping number of characters larger than the internal buffer.
-     *
-     * @throws Throwable
-     *             for some failure scenarios.
-     */
-    @Test
-    public void testSkipBig() throws Throwable {
-        final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
-            assertEquals(3, b32stream.skip(1024));
-            // End of stream reached
-            assertEquals(-1, b32stream.read());
-            assertEquals(-1, b32stream.read());
-        }
-    }
-
     /**
      * Tests skipping past the end of a stream.
      *
