@@ -35,7 +35,6 @@ import org.apache.commons.codec.CodecPolicy;
 import org.junit.jupiter.api.Test;
 
 /**
- * @since 1.4
  */
 public class Base64InputStreamTest {
 
@@ -50,105 +49,6 @@ public class Base64InputStreamTest {
 
     private static final String STRING_FIXTURE = "Hello World";
 
-    /**
-     * Tests the problem reported in CODEC-130. Missing / wrong implementation of skip.
-     */
-    @Test
-    public void testCodec130() throws IOException {
-        final ByteArrayOutputStream bos = new ByteArrayOutputStream();
-        try (final Base64OutputStream base64os = new Base64OutputStream(bos)) {
-            base64os.write(StringUtils.getBytesUtf8(STRING_FIXTURE));
-        }
-
-        final ByteArrayInputStream bis = new ByteArrayInputStream(bos.toByteArray());
-        final Base64InputStream ins = new Base64InputStream(bis);
-
-        // we skip the first character read from the reader
-        ins.skip(1);
-        final byte[] decodedBytes = BaseNTestData.streamToBytes(ins, new byte[64]);
-        final String str = StringUtils.newStringUtf8(decodedBytes);
-
-        assertEquals(STRING_FIXTURE.substring(1), str);
-    }
-
-    /**
-     * Tests the bug reported in CODEC-105. Bad interactions with InputStream when reading one byte at a time.
-     */
-    @Test
-    public void testCodec105() throws IOException {
-        try (final Base64InputStream in = new Base64InputStream(new Codec105ErrorInputStream(), true, 0, null)) {
-            for (int i = 0; i < 5; i++) {
-                in.read();
-            }
-        }
-    }
-
-    /**
-     * Test for the CODEC-101 bug: InputStream.read(byte[]) should never return 0 because Java's builtin InputStreamReader hates that.
-     *
-     * @throws Exception
-     *             for some failure scenarios.
-     */
-    @Test
-    public void testCodec101() throws Exception {
-        final byte[] codec101 = StringUtils.getBytesUtf8(Base64TestData.CODEC_101_INPUT_LENGTH_IS_MULTIPLE_OF_3);
-        final ByteArrayInputStream bais = new ByteArrayInputStream(codec101);
-        try (final Base64InputStream in = new Base64InputStream(bais)) {
-            final byte[] result = new byte[8192];
-            int c = in.read(result);
-            assertTrue(c > 0, "Codec101: First read successful [c=" + c + "]");
-
-            c = in.read(result);
-            assertTrue(c < 0, "Codec101: Second read should report end-of-stream [c=" + c + "]");
-        }
-    }
-
-    /**
-     * Another test for the CODEC-101 bug: In commons-codec-1.4 this test shows InputStreamReader explicitly hating an
-     * InputStream.read(byte[]) return of 0:
-     *
-     * java.io.IOException: Underlying input stream returned zero bytes at sun.nio.cs.StreamDecoder.readBytes(StreamDecoder.java:268) at
-     * sun.nio.cs.StreamDecoder.implRead(StreamDecoder.java:306) at sun.nio.cs.StreamDecoder.read(StreamDecoder.java:158) at
-     * java.io.InputStreamReader.read(InputStreamReader.java:167) at java.io.BufferedReader.fill(BufferedReader.java:136) at
-     * java.io.BufferedReader.readLine(BufferedReader.java:299) at java.io.BufferedReader.readLine(BufferedReader.java:362) at
-     * org.apache.commons.codec.binary.Base64InputStreamTest.testInputStreamReader(Base64InputStreamTest.java:75)
-     *
-     * But in commons-codec-1.5 it's fixed. :-)
-     *
-     * @throws Exception
-     *             for some failure scenarios.
-     */
-    @Test
-    public void testInputStreamReader() throws Exception {
-        final byte[] codec101 = StringUtils.getBytesUtf8(Base64TestData.CODEC_101_INPUT_LENGTH_IS_MULTIPLE_OF_3);
-        final ByteArrayInputStream bais = new ByteArrayInputStream(codec101);
-        final Base64InputStream in = new Base64InputStream(bais);
-        final InputStreamReader isr = new InputStreamReader(in);
-        try (final BufferedReader br = new BufferedReader(isr)) {
-            final String line = br.readLine();
-            assertNotNull(line, "Codec101:  InputStreamReader works!");
-        }
-    }
-
-    /**
-     * Test the Base64InputStream implementation against the special NPE inducing input identified in the CODEC-98 bug.
-     *
-     * @throws Exception
-     *             for some failure scenarios.
-     */
-    @Test
-    public void testCodec98NPE() throws Exception {
-        final byte[] codec98 = StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
-        final ByteArrayInputStream data = new ByteArrayInputStream(codec98);
-        final Base64InputStream stream = new Base64InputStream(data);
-
-        // This line causes an NPE in commons-codec-1.4.jar:
-        final byte[] decodedBytes = BaseNTestData.streamToBytes(stream, new byte[1024]);
-
-        final String decoded = StringUtils.newStringUtf8(decodedBytes);
-        assertEquals(Base64TestData.CODEC_98_NPE_DECODED, decoded, "codec-98 NPE Base64InputStream");
-    }
-
     /**
      * Tests skipping past the end of a stream.
      *
@@ -169,6 +69,13 @@ public class Base64InputStreamTest {
         }
     }
 
+    private void testBase64EmptyInputStream(final int chuckSize) throws Exception {
+        final byte[] emptyEncoded = {};
+        final byte[] emptyDecoded = {};
+        testByteByByte(emptyEncoded, emptyDecoded, chuckSize, CRLF);
+        testByChunk(emptyEncoded, emptyDecoded, chuckSize, CRLF);
+    }
+
     /**
      * Tests the Base64InputStream implementation against empty input.
      *
@@ -191,13 +98,6 @@ public class Base64InputStreamTest {
         testBase64EmptyInputStream(BaseNCodec.PEM_CHUNK_SIZE);
     }
 
-    private void testBase64EmptyInputStream(final int chuckSize) throws Exception {
-        final byte[] emptyEncoded = {};
-        final byte[] emptyDecoded = {};
-        testByteByByte(emptyEncoded, emptyDecoded, chuckSize, CRLF);
-        testByChunk(emptyEncoded, emptyDecoded, chuckSize, CRLF);
-    }
-
     /**
      * Tests the Base64InputStream implementation.
      *
@@ -295,21 +195,17 @@ public class Base64InputStreamTest {
      *             Usually signifies a bug in the Base64 commons-codec implementation.
      */
     private void testByChunk(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
-
         // Start with encode.
-        InputStream in;
-        in = new Base64InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator);
-        byte[] output = BaseNTestData.streamToBytes(in);
-
-        assertEquals(-1, in.read(), "EOF");
-        assertEquals(-1, in.read(), "Still EOF");
-        assertArrayEquals(encoded, output, "Streaming base64 encode");
-
-        in.close();
+        try (InputStream in = new Base64InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator)) {
+            final byte[] output = BaseNTestData.streamToBytes(in);
+            assertEquals(-1, in.read(), "EOF");
+            assertEquals(-1, in.read(), "Still EOF");
+            assertArrayEquals(encoded, output, "Streaming base64 encode");
+        }
 
         // Now let's try to decode.
-        in = new Base64InputStream(new ByteArrayInputStream(encoded));
-        output = BaseNTestData.streamToBytes(in);
+        InputStream in = new Base64InputStream(new ByteArrayInputStream(encoded));
+        byte[] output = BaseNTestData.streamToBytes(in);
 
         assertEquals(-1, in.read(), "EOF");
         assertEquals(-1, in.read(), "Still EOF");
@@ -348,35 +244,32 @@ public class Base64InputStreamTest {
      *             Usually signifies a bug in the Base64 commons-codec implementation.
      */
     private void testByteByByte(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
-
-        // Start with encode.
-        InputStream in;
-        in = new Base64InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator);
         byte[] output = new byte[encoded.length];
-        for (int i = 0; i < output.length; i++) {
-            output[i] = (byte) in.read();
+        // Start with encode.
+        try (InputStream in = new Base64InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator)) {
+            for (int i = 0; i < output.length; i++) {
+                output[i] = (byte) in.read();
+            }
+
+            assertEquals(-1, in.read(), "EOF");
+            assertEquals(-1, in.read(), "Still EOF");
+            assertArrayEquals(encoded, output, "Streaming base64 encode");
+
         }
-
-        assertEquals(-1, in.read(), "EOF");
-        assertEquals(-1, in.read(), "Still EOF");
-        assertArrayEquals(encoded, output, "Streaming base64 encode");
-
-        in.close();
         // Now let's try to decode.
-        in = new Base64InputStream(new ByteArrayInputStream(encoded));
-        output = new byte[decoded.length];
-        for (int i = 0; i < output.length; i++) {
-            output[i] = (byte) in.read();
+        try (InputStream in = new Base64InputStream(new ByteArrayInputStream(encoded))) {
+            output = new byte[decoded.length];
+            for (int i = 0; i < output.length; i++) {
+                output[i] = (byte) in.read();
+            }
+
+            assertEquals(-1, in.read(), "EOF");
+            assertEquals(-1, in.read(), "Still EOF");
+            assertArrayEquals(decoded, output, "Streaming base64 decode");
         }
 
-        assertEquals(-1, in.read(), "EOF");
-        assertEquals(-1, in.read(), "Still EOF");
-        assertArrayEquals(decoded, output, "Streaming base64 decode");
-
-        in.close();
-
         // I always wanted to do this! (wrap encoder with decoder etc.).
-        in = new ByteArrayInputStream(decoded);
+        InputStream in = new ByteArrayInputStream(decoded);
         for (int i = 0; i < 10; i++) {
             in = new Base64InputStream(in, true, chunkSize, separator);
             in = new Base64InputStream(in, false);
@@ -389,7 +282,105 @@ public class Base64InputStreamTest {
         assertEquals(-1, in.read(), "EOF");
         assertEquals(-1, in.read(), "Still EOF");
         assertArrayEquals(decoded, output, "Streaming base64 wrap-wrap-wrap!");
-        in.close();
+    }
+
+    /**
+     * Test for the CODEC-101 bug: InputStream.read(byte[]) should never return 0 because Java's builtin InputStreamReader hates that.
+     *
+     * @throws Exception
+     *             for some failure scenarios.
+     */
+    @Test
+    public void testCodec101() throws Exception {
+        final byte[] codec101 = StringUtils.getBytesUtf8(Base64TestData.CODEC_101_INPUT_LENGTH_IS_MULTIPLE_OF_3);
+        final ByteArrayInputStream bais = new ByteArrayInputStream(codec101);
+        try (final Base64InputStream in = new Base64InputStream(bais)) {
+            final byte[] result = new byte[8192];
+            int c = in.read(result);
+            assertTrue(c > 0, "Codec101: First read successful [c=" + c + "]");
+
+            c = in.read(result);
+            assertTrue(c < 0, "Codec101: Second read should report end-of-stream [c=" + c + "]");
+        }
+    }
+
+    /**
+     * Tests the bug reported in CODEC-105. Bad interactions with InputStream when reading one byte at a time.
+     */
+    @Test
+    public void testCodec105() throws IOException {
+        try (final Base64InputStream in = new Base64InputStream(new Codec105ErrorInputStream(), true, 0, null)) {
+            for (int i = 0; i < 5; i++) {
+                in.read();
+            }
+        }
+    }
+
+    /**
+     * Tests the problem reported in CODEC-130. Missing / wrong implementation of skip.
+     */
+    @Test
+    public void testCodec130() throws IOException {
+        final ByteArrayOutputStream bos = new ByteArrayOutputStream();
+        try (final Base64OutputStream base64os = new Base64OutputStream(bos)) {
+            base64os.write(StringUtils.getBytesUtf8(STRING_FIXTURE));
+        }
+
+        final ByteArrayInputStream bis = new ByteArrayInputStream(bos.toByteArray());
+        final Base64InputStream ins = new Base64InputStream(bis);
+
+        // we skip the first character read from the reader
+        ins.skip(1);
+        final byte[] decodedBytes = BaseNTestData.streamToBytes(ins, new byte[64]);
+        final String str = StringUtils.newStringUtf8(decodedBytes);
+
+        assertEquals(STRING_FIXTURE.substring(1), str);
+    }
+
+    /**
+     * Test the Base64InputStream implementation against the special NPE inducing input identified in the CODEC-98 bug.
+     *
+     * @throws Exception
+     *             for some failure scenarios.
+     */
+    @Test
+    public void testCodec98NPE() throws Exception {
+        final byte[] codec98 = StringUtils.getBytesUtf8(Base64TestData.CODEC_98_NPE);
+        final ByteArrayInputStream data = new ByteArrayInputStream(codec98);
+        final Base64InputStream stream = new Base64InputStream(data);
+
+        // This line causes an NPE in commons-codec-1.4.jar:
+        final byte[] decodedBytes = BaseNTestData.streamToBytes(stream, new byte[1024]);
+
+        final String decoded = StringUtils.newStringUtf8(decodedBytes);
+        assertEquals(Base64TestData.CODEC_98_NPE_DECODED, decoded, "codec-98 NPE Base64InputStream");
+    }
+
+    /**
+     * Another test for the CODEC-101 bug: In commons-codec-1.4 this test shows InputStreamReader explicitly hating an
+     * InputStream.read(byte[]) return of 0:
+     *
+     * java.io.IOException: Underlying input stream returned zero bytes at sun.nio.cs.StreamDecoder.readBytes(StreamDecoder.java:268) at
+     * sun.nio.cs.StreamDecoder.implRead(StreamDecoder.java:306) at sun.nio.cs.StreamDecoder.read(StreamDecoder.java:158) at
+     * java.io.InputStreamReader.read(InputStreamReader.java:167) at java.io.BufferedReader.fill(BufferedReader.java:136) at
+     * java.io.BufferedReader.readLine(BufferedReader.java:299) at java.io.BufferedReader.readLine(BufferedReader.java:362) at
+     * org.apache.commons.codec.binary.Base64InputStreamTest.testInputStreamReader(Base64InputStreamTest.java:75)
+     *
+     * But in commons-codec-1.5 it's fixed. :-)
+     *
+     * @throws Exception
+     *             for some failure scenarios.
+     */
+    @Test
+    public void testInputStreamReader() throws Exception {
+        final byte[] codec101 = StringUtils.getBytesUtf8(Base64TestData.CODEC_101_INPUT_LENGTH_IS_MULTIPLE_OF_3);
+        final ByteArrayInputStream bais = new ByteArrayInputStream(codec101);
+        final Base64InputStream in = new Base64InputStream(bais);
+        final InputStreamReader isr = new InputStreamReader(in);
+        try (final BufferedReader br = new BufferedReader(isr)) {
+            final String line = br.readLine();
+            assertNotNull(line, "Codec101:  InputStreamReader works!");
+        }
     }
 
     /**
@@ -408,6 +399,24 @@ public class Base64InputStreamTest {
         }
     }
 
+    /**
+     * Tests read returning 0
+     *
+     * @throws Exception
+     *             for some failure scenarios.
+     */
+    @Test
+    public void testRead0() throws Exception {
+        final byte[] decoded = StringUtils.getBytesUtf8(STRING_FIXTURE);
+        final byte[] buf = new byte[1024];
+        int bytesRead = 0;
+        final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
+        try (final Base64InputStream in = new Base64InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
+            bytesRead = in.read(buf, 0, 0);
+            assertEquals(0, bytesRead, "Base64InputStream.read(buf, 0, 0) returns 0");
+        }
+    }
+
     /**
      * Tests read using different buffer sizes
      *
@@ -432,24 +441,6 @@ public class Base64InputStreamTest {
         assertArrayEquals(decoded, out.toByteArray());
     }
 
-    /**
-     * Tests read returning 0
-     *
-     * @throws Exception
-     *             for some failure scenarios.
-     */
-    @Test
-    public void testRead0() throws Exception {
-        final byte[] decoded = StringUtils.getBytesUtf8(STRING_FIXTURE);
-        final byte[] buf = new byte[1024];
-        int bytesRead = 0;
-        final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        try (final Base64InputStream in = new Base64InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
-            bytesRead = in.read(buf, 0, 0);
-            assertEquals(0, bytesRead, "Base64InputStream.read(buf, 0, 0) returns 0");
-        }
-    }
-
     /**
      * Tests read with null.
      *
