@@ -33,73 +33,6 @@ import org.junit.jupiter.api.Test;
  */
 public class CharSequenceUtilsTest {
 
-    static class TestData{
-        final String source;
-        final boolean ignoreCase;
-        final int toffset;
-        final String other;
-        final int ooffset;
-        final int len;
-        final boolean expected;
-        final Class<? extends Throwable> throwable;
-        TestData(final String source, final boolean ignoreCase, final int toffset,
-                final String other, final int ooffset, final int len, final boolean expected) {
-            this.source = source;
-            this.ignoreCase = ignoreCase;
-            this.toffset = toffset;
-            this.other = other;
-            this.ooffset = ooffset;
-            this.len = len;
-            this.expected = expected;
-            this.throwable = null;
-        }
-        TestData(final String source, final boolean ignoreCase, final int toffset,
-                final String other, final int ooffset, final int len, final Class<? extends Throwable> throwable) {
-            this.source = source;
-            this.ignoreCase = ignoreCase;
-            this.toffset = toffset;
-            this.other = other;
-            this.ooffset = ooffset;
-            this.len = len;
-            this.expected = false;
-            this.throwable = throwable;
-        }
-        @Override
-        public String toString() {
-            final StringBuilder sb = new StringBuilder();
-            sb.append(source).append("[").append(toffset).append("]");
-            sb.append(ignoreCase? " caseblind ":" samecase ");
-            sb.append(other).append("[").append(ooffset).append("]");
-            sb.append(" ").append(len).append(" => ");
-            if (throwable != null) {
-                sb.append(throwable);
-            } else {
-                sb.append(expected);
-            }
-            return sb.toString();
-        }
-    }
-
-    // Note: The commented out tests fail due to the CharSequenceUtils method
-    // being based on Lang 3.3.2 and the tests are from 3.11.
-
-    private static final TestData[] TEST_DATA = {
-            //          Source  IgnoreCase Offset Other  Offset Length Result
-            //new TestData("",    true,      -1,    "",    -1,    -1,    false),
-            //new TestData("",    true,      0,     "",    0,     1,     false),
-            new TestData("a",   true,      0,     "abc", 0,     0,     true),
-            new TestData("a",   true,      0,     "abc", 0,     1,     true),
-            //new TestData("a",   true,      0,     null,  0,     0,     NullPointerException.class),
-            //new TestData(null,  true,      0,     null,  0,     0,     NullPointerException.class),
-            //new TestData(null,  true,      0,     "",    0,     0,     NullPointerException.class),
-            new TestData("Abc", true,      0,     "abc", 0,     3,     true),
-            new TestData("Abc", false,     0,     "abc", 0,     3,     false),
-            new TestData("Abc", true,      1,     "abc", 1,     2,     true),
-            new TestData("Abc", false,     1,     "abc", 1,     2,     true),
-            new TestData("Abcd", true,      1,     "abcD", 1,     2,     true),
-            new TestData("Abcd", false,     1,     "abcD", 1,     2,     true),
-    };
-
     private abstract static class RunTest {
 
         abstract boolean invoke();
@@ -122,6 +55,87 @@ public class CharSequenceUtilsTest {
 
     }
 
+    // Note: The commented out tests fail due to the CharSequenceUtils method
+    // being based on Lang 3.3.2 and the tests are from 3.11.
+
+    static class TestData {
+
+        final String source;
+        final boolean ignoreCase;
+        final int toffset;
+        final String other;
+        final int ooffset;
+        final int len;
+        final boolean expected;
+        final Class<? extends Throwable> throwable;
+
+        TestData(final String source, final boolean ignoreCase, final int toffset, final String other, final int ooffset, final int len,
+                final boolean expected) {
+            this.source = source;
+            this.ignoreCase = ignoreCase;
+            this.toffset = toffset;
+            this.other = other;
+            this.ooffset = ooffset;
+            this.len = len;
+            this.expected = expected;
+            this.throwable = null;
+        }
+
+        TestData(final String source, final boolean ignoreCase, final int toffset, final String other, final int ooffset, final int len,
+                final Class<? extends Throwable> throwable) {
+            this.source = source;
+            this.ignoreCase = ignoreCase;
+            this.toffset = toffset;
+            this.other = other;
+            this.ooffset = ooffset;
+            this.len = len;
+            this.expected = false;
+            this.throwable = throwable;
+        }
+
+        @Override
+        public String toString() {
+            final StringBuilder sb = new StringBuilder();
+            sb.append(source).append("[").append(toffset).append("]");
+            sb.append(ignoreCase ? " caseblind " : " samecase ");
+            sb.append(other).append("[").append(ooffset).append("]");
+            sb.append(" ").append(len).append(" => ");
+            if (throwable != null) {
+                sb.append(throwable);
+            } else {
+                sb.append(expected);
+            }
+            return sb.toString();
+        }
+    }
+
+    private static final TestData[] TEST_DATA = {
+            //          Source  IgnoreCase Offset Other  Offset Length Result
+            //new TestData("",    true,      -1,    "",    -1,    -1,    false),
+            //new TestData("",    true,      0,     "",    0,     1,     false),
+            new TestData("a",   true,      0,     "abc", 0,     0,     true),
+            new TestData("a",   true,      0,     "abc", 0,     1,     true),
+            //new TestData("a",   true,      0,     null,  0,     0,     NullPointerException.class),
+            //new TestData(null,  true,      0,     null,  0,     0,     NullPointerException.class),
+            //new TestData(null,  true,      0,     "",    0,     0,     NullPointerException.class),
+            new TestData("Abc", true,      0,     "abc", 0,     3,     true),
+            new TestData("Abc", false,     0,     "abc", 0,     3,     false),
+            new TestData("Abc", true,      1,     "abc", 1,     2,     true),
+            new TestData("Abc", false,     1,     "abc", 1,     2,     true),
+            new TestData("Abcd", true,      1,     "abcD", 1,     2,     true),
+            new TestData("Abcd", false,     1,     "abcD", 1,     2,     true),
+    };
+
+    /**
+     * Test the constructor exists. This is here for code coverage. The class ideally should
+     * be package private, marked as final and have a private constructor to prevent instances.
+     */
+    @SuppressWarnings("unused")
+    @Test
+    public void testConstructor() {
+        new CharSequenceUtils();
+    }
+
     @Test
     public void testRegionMatches() {
         for (final TestData data : TEST_DATA) {
@@ -145,14 +159,4 @@ public class CharSequenceUtilsTest {
             }.run(data, "CSNonString");
         }
     }
-
-    /**
-     * Test the constructor exists. This is here for code coverage. The class ideally should
-     * be package private, marked as final and have a private constructor to prevent instances.
-     */
-    @SuppressWarnings("unused")
-    @Test
-    public void testConstructor() {
-        new CharSequenceUtils();
-    }
 }
