@@ -23,8 +23,6 @@ import org.junit.jupiter.api.Test;
 
 /**
  * Tests {@link Digest}.
- *
- * @since 1.17
  */
 public class DigestTest {
 
@@ -40,6 +38,6 @@ public class DigestTest {
      */
     @Test
     public void testNullArguments() {
-        assertThrows(IllegalArgumentException.class, () -> Digest.main(null));
+        assertThrows(NullPointerException.class, () -> Digest.main(null));
     }
 }
