@@ -22,7 +22,7 @@ import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
-import org.apache.commons.codec.StringEncoderAbstractTest;
+import org.apache.commons.codec.AbstractStringEncoderTest;
 import org.junit.jupiter.api.Test;
 
 /**
@@ -33,258 +33,261 @@ import org.junit.jupiter.api.Test;
  *
  * An unusual value is indicated by the term "corner case"
  */
-public class MatchRatingApproachEncoderTest extends StringEncoderAbstractTest<MatchRatingApproachEncoder> {
+public class MatchRatingApproachEncoderTest extends AbstractStringEncoderTest<MatchRatingApproachEncoder> {
 
-    // ********** BEGIN REGION - TEST SUPPORT METHODS
+    @Override
+    protected MatchRatingApproachEncoder createStringEncoder() {
+        return new MatchRatingApproachEncoder();
+    }
 
     @Test
     public final void testAccentRemoval_AllLower_SuccessfullyRemoved() {
-        assertEquals("aeiou", this.getStringEncoder().removeAccents("áéíóú"));
-    }
-
-    @Test
-    public final void testAccentRemoval_WithSpaces_SuccessfullyRemovedAndSpacesInvariant() {
-        assertEquals("ae io  u", this.getStringEncoder().removeAccents("áé íó  ú"));
-    }
-
-    @Test
-    public final void testAccentRemoval_UpperAndLower_SuccessfullyRemovedAndCaseInvariant() {
-        assertEquals("AeiOuu", this.getStringEncoder().removeAccents("ÁeíÓuu"));
-    }
-
-    @Test
-    public final void testAccentRemoval_MixedWithUnusualChars_SuccessfullyRemovedAndUnusualCharactersInvariant() {
-        assertEquals("A-e'i.,o&u", this.getStringEncoder().removeAccents("Á-e'í.,ó&ú"));
-    }
-
-    @Test
-    public final void testAccentRemoval_GerSpanFrenMix_SuccessfullyRemoved() {
-        assertEquals("aeoußAEOUnNa", this.getStringEncoder().removeAccents("äëöüßÄËÖÜñÑà"));
+        assertEquals("aeiou", getStringEncoder().removeAccents("áéíóú"));
     }
 
     @Test
     public final void testAccentRemoval_ComprehensiveAccentMix_AllSuccessfullyRemoved() {
-        assertEquals("E,E,E,E,U,U,I,I,A,A,O,e,e,e,e,u,u,i,i,a,a,o,c",
-                this.getStringEncoder().removeAccents("È,É,Ê,Ë,Û,Ù,Ï,Î,À,Â,Ô,è,é,ê,ë,û,ù,ï,î,à,â,ô,ç"));
+        assertEquals("E,E,E,E,U,U,I,I,A,A,O,e,e,e,e,u,u,i,i,a,a,o,c", getStringEncoder().removeAccents("È,É,Ê,Ë,Û,Ù,Ï,Î,À,Â,Ô,è,é,ê,ë,û,ù,ï,î,à,â,ô,ç"));
     }
 
     @Test
-    public final void testAccentRemovalNormalString_NoChange() {
-        assertEquals("Colorless green ideas sleep furiously", this.getStringEncoder().removeAccents("Colorless green ideas sleep furiously"));
+    public final void testAccentRemoval_GerSpanFrenMix_SuccessfullyRemoved() {
+        assertEquals("aeoußAEOUnNa", getStringEncoder().removeAccents("äëöüßÄËÖÜñÑà"));
+    }
+
+    @Test
+    public final void testAccentRemoval_MixedWithUnusualChars_SuccessfullyRemovedAndUnusualCharactersInvariant() {
+        assertEquals("A-e'i.,o&u", getStringEncoder().removeAccents("Á-e'í.,ó&ú"));
     }
 
     @Test
     public final void testAccentRemoval_NINO_NoChange() {
-        assertEquals("", this.getStringEncoder().removeAccents(""));
+        assertEquals("", getStringEncoder().removeAccents(""));
     }
 
     @Test
     public final void testAccentRemoval_NullValue_ReturnNullSuccessfully() {
-        assertNull(this.getStringEncoder().removeAccents(null));
+        assertNull(getStringEncoder().removeAccents(null));
     }
 
     @Test
-    public final void testRemoveSingleDoubleConsonants_BUBLE_RemovedSuccessfully() {
-        assertEquals("BUBLE", this.getStringEncoder().removeDoubleConsonants("BUBBLE"));
+    public final void testAccentRemoval_UpperAndLower_SuccessfullyRemovedAndCaseInvariant() {
+        assertEquals("AeiOuu", getStringEncoder().removeAccents("ÁeíÓuu"));
     }
 
     @Test
-    public final void testRemoveDoubleConsonants_MISSISSIPPI_RemovedSuccessfully() {
-        assertEquals("MISISIPI", this.getStringEncoder().removeDoubleConsonants("MISSISSIPPI"));
+    public final void testAccentRemoval_WithSpaces_SuccessfullyRemovedAndSpacesInvariant() {
+        assertEquals("ae io  u", getStringEncoder().removeAccents("áé íó  ú"));
     }
 
     @Test
-    public final void testRemoveDoubleDoubleVowel_BEETLE_NotRemoved() {
-        assertEquals("BEETLE", this.getStringEncoder().removeDoubleConsonants("BEETLE"));
-    }
-
-    @Test
-    public final void testIsVowel_CapitalA_ReturnsTrue() {
-        assertTrue(this.getStringEncoder().isVowel("A"));
-    }
-
-    @Test
-    public final void testIsVowel_SmallD_ReturnsFalse() {
-        assertFalse(this.getStringEncoder().isVowel("d"));
-    }
-
-    @Test
-    public final void testRemoveVowel_ALESSANDRA_Returns_ALSSNDR() {
-        assertEquals("ALSSNDR", this.getStringEncoder().removeVowels("ALESSANDRA"));
-    }
-
-    @Test
-    public final void testRemoveVowel__AIDAN_Returns_ADN() {
-        assertEquals("ADN", this.getStringEncoder().removeVowels("AIDAN"));
-    }
-
-    @Test
-    public final void testRemoveVowel__DECLAN_Returns_DCLN() {
-        assertEquals("DCLN", this.getStringEncoder().removeVowels("DECLAN"));
-    }
-
-    @Test
-    public final void testGetFirstLast3__ALEXANDER_Returns_Aleder() {
-        assertEquals("Aleder", this.getStringEncoder().getFirst3Last3("Alexzander"));
-    }
-
-    @Test
-    public final void testGetFirstLast3_PETE_Returns_PETE() {
-        assertEquals("PETE", this.getStringEncoder().getFirst3Last3("PETE"));
-    }
-
-    @Test
-    public final void testLeftToRightThenRightToLeft_ALEXANDER_ALEXANDRA_Returns4() {
-        assertEquals(4, this.getStringEncoder().leftToRightThenRightToLeftProcessing("ALEXANDER", "ALEXANDRA"));
-    }
-
-    @Test
-    public final void testLeftToRightThenRightToLeft_EINSTEIN_MICHAELA_Returns0() {
-        assertEquals(0, this.getStringEncoder().leftToRightThenRightToLeftProcessing("EINSTEIN", "MICHAELA"));
-    }
-
-    @Test
-    public final void testGetMinRating_7_Return4_Successfully() {
-        assertEquals(4, this.getStringEncoder().getMinRating(7));
-    }
-
-    @Test
-    public final void testGetMinRating_1_Returns5_Successfully() {
-        assertEquals(5, this.getStringEncoder().getMinRating(1));
-    }
-
-    @Test
-    public final void testGetMinRating_2_Returns5_Successfully() {
-        assertEquals(5, this.getStringEncoder().getMinRating(2));
-    }
-
-    @Test
-    public final void testgetMinRating_5_Returns4_Successfully(){
-        assertEquals(4, this.getStringEncoder().getMinRating(5));
-    }
-
-    @Test
-    public final void testgetMinRating_5_Returns4_Successfully2(){
-        assertEquals(4, this.getStringEncoder().getMinRating(5));
-    }
-
-    @Test
-    public final void testgetMinRating_6_Returns4_Successfully(){
-        assertEquals(4, this.getStringEncoder().getMinRating(6));
-    }
-
-    @Test
-    public final void testgetMinRating_7_Returns4_Successfully(){
-        assertEquals(4, this.getStringEncoder().getMinRating(7));
-    }
-
-    @Test
-    public final void testgetMinRating_8_Returns3_Successfully(){
-        assertEquals(3, this.getStringEncoder().getMinRating(8));
-    }
-
-    @Test
-    public final void testgetMinRating_10_Returns3_Successfully(){
-        assertEquals(3, this.getStringEncoder().getMinRating(10));
-    }
-
-    @Test
-    public final void testgetMinRating_11_Returns_3_Successfully(){
-        assertEquals(3, this.getStringEncoder().getMinRating(11));
-    }
-
-    @Test
-    public final void testGetMinRating_13_Returns_1_Successfully() {
-        assertEquals(1, this.getStringEncoder().getMinRating(13));
+    public final void testAccentRemovalNormalString_NoChange() {
+        assertEquals("Colorless green ideas sleep furiously", getStringEncoder().removeAccents("Colorless green ideas sleep furiously"));
     }
 
     @Test
     public final void testCleanName_SuccessfullyClean() {
-        assertEquals("THISISATEST", this.getStringEncoder().cleanName("This-ís   a t.,es &t"));
+        assertEquals("THISISATEST", getStringEncoder().cleanName("This-ís   a t.,es &t"));
     }
 
     @Test
-    public final void testIsVowel_SingleVowel_ReturnsTrue() {
-        assertTrue(this.getStringEncoder().isVowel(("I")));
+    public final void testCompare_BRIAN_BRYAN_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Brian", "Bryan"));
     }
 
     @Test
-    public final void testIsEncodeEquals_CornerCase_SecondNameNothing_ReturnsFalse() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("test", ""));
+    public final void testCompare_BURNS_BOURNE_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Burns", "Bourne"));
     }
 
     @Test
-    public final void testIsEncodeEquals_CornerCase_FirstNameNothing_ReturnsFalse() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("", "test"));
+    public final void testCompare_CATHERINE_KATHRYN_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Catherine", "Kathryn"));
     }
 
     @Test
-    public final void testIsEncodeEquals_CornerCase_SecondNameJustSpace_ReturnsFalse() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("test", " "));
+    public final void testCompare_COLM_COLIN_WithAccentsAndSymbolsAndSpaces_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Cólm.   ", "C-olín"));
     }
 
     @Test
-    public final void testIsEncodeEquals_CornerCase_FirstNameJustSpace_ReturnsFalse() {
-        assertFalse(this.getStringEncoder().isEncodeEquals(" ", "test"));
+    public final void testCompare_Forenames_SEAN_JOHN_MatchExpected() {
+        assertTrue(getStringEncoder().isEncodeEquals("Sean", "John"));
     }
 
     @Test
-    public final void testIsEncodeEquals_CornerCase_SecondNameNull_ReturnsFalse() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("test", null));
+    public final void testCompare_Forenames_SEAN_PETE_NoMatchExpected() {
+        assertFalse(getStringEncoder().isEncodeEquals("Sean", "Pete"));
     }
 
     @Test
-    public final void testIsEncodeEquals_CornerCase_FirstNameNull_ReturnsFalse() {
-        assertFalse(this.getStringEncoder().isEncodeEquals(null, "test"));
+    public final void testCompare_Forenames_UNA_OONAGH_ShouldSuccessfullyMatchButDoesNot() {
+        assertFalse(getStringEncoder().isEncodeEquals("Úna", "Oonagh")); // Disappointing
     }
 
     @Test
-    public final void testIsEncodeEquals_CornerCase_FirstNameJust1Letter_ReturnsFalse() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("t", "test"));
+    public final void testCompare_FRANCISZEK_FRANCES_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Franciszek", "Frances"));
     }
 
     @Test
-    public final void testIsEncodeEqualsSecondNameJust1Letter_ReturnsFalse() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("test", "t"));
-    }
-
-    // ***** END REGION - TEST SUPPORT METHODS
-
-    // ***** BEGIN REGION - TEST GET MRA ENCODING
-
-    @Test
-    public final void testGetEncoding_HARPER_HRPR() {
-        assertEquals("HRPR", this.getStringEncoder().encode("HARPER"));
+    public final void testCompare_KARL_ALESSANDRO_DoesNotMatch() {
+        assertFalse(getStringEncoder().isEncodeEquals("Karl", "Alessandro"));
     }
 
     @Test
-    public final void testGetEncoding_SMITH_to_SMTH() {
-        assertEquals("SMTH", this.getStringEncoder().encode("Smith"));
+    public final void testCompare_LongSurnames_MORIARTY_OMUIRCHEARTAIGH_DoesNotSuccessfulMatch() {
+        assertFalse(getStringEncoder().isEncodeEquals("Moriarty", "OMuircheartaigh"));
     }
 
     @Test
-    public final void testGetEncoding_SMYTH_to_SMYTH() {
-        assertEquals("SMYTH", this.getStringEncoder().encode("Smyth"));
+    public final void testCompare_LongSurnames_OMUIRCHEARTAIGH_OMIREADHAIGH_SuccessfulMatch() {
+        assertTrue(getStringEncoder().isEncodeEquals("o'muireadhaigh", "Ó 'Muircheartaigh "));
     }
 
     @Test
-    public final void testGetEncoding_Space_to_Nothing() {
-        assertEquals("", this.getStringEncoder().encode(" "));
+    public final void testCompare_MCGOWAN_MCGEOGHEGAN_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("McGowan", "Mc Geoghegan"));
     }
 
     @Test
-    public final void testGetEncoding_NoSpace_to_Nothing() {
-        assertEquals("", this.getStringEncoder().encode(""));
+    public final void testCompare_MICKY_MICHAEL_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Micky", "Michael"));
     }
 
     @Test
-    public final void testGetEncoding_Null_to_Nothing() {
-        assertEquals("", this.getStringEncoder().encode(null));
+    public final void testCompare_OONA_OONAGH_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Oona", "Oonagh"));
     }
 
     @Test
-    public final void testGetEncoding_One_Letter_to_Nothing() {
-        assertEquals("", this.getStringEncoder().encode("E"));
+    public final void testCompare_PETERSON_PETERS_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Peterson", "Peters"));
+    }
+
+    @Test
+    public final void testCompare_SAM_SAMUEL_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Sam", "Samuel"));
+    }
+
+    @Test
+    public final void testCompare_SEAN_SHAUN_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Séan", "Shaun"));
+    }
+
+    @Test
+    public final void testCompare_ShortNames_AL_ED_WorksButNoMatch() {
+        assertFalse(getStringEncoder().isEncodeEquals("Al", "Ed"));
+    }
+
+    @Test
+    public final void testCompare_SmallInput_CARK_Kl_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Kl", "Karl"));
+    }
+
+    @Test
+    public final void testCompare_SMITH_SMYTH_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("smith", "smyth"));
+    }
+
+    @Test
+    public final void testCompare_SOPHIE_SOFIA_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Sophie", "Sofia"));
+    }
+
+    @Test
+    public final void testCompare_STEPHEN_STEFAN_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Stephen", "Stefan"));
+    }
+
+    @Test
+    public final void testCompare_STEPHEN_STEVEN_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Stephen", "Steven"));
+    }
+
+    @Test
+    public final void testCompare_STEVEN_STEFAN_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Steven", "Stefan"));
+    }
+
+    @Test
+    public final void testCompare_Surname_AUERBACH_UHRBACH_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Auerbach", "Uhrbach"));
+    }
+
+    @Test
+    public final void testCompare_Surname_COOPERFLYNN_SUPERLYN_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Cooper-Flynn", "Super-Lyn"));
+    }
+
+    @Test
+    public final void testCompare_Surname_HAILEY_HALLEY_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Hailey", "Halley"));
+    }
+
+    @Test
+    public final void testCompare_Surname_LEWINSKY_LEVINSKI_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("LEWINSKY", "LEVINSKI"));
+    }
+
+    @Test
+    public final void testCompare_Surname_LIPSHITZ_LIPPSZYC_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("LIPSHITZ", "LIPPSZYC"));
+    }
+
+    @Test
+    public final void testCompare_Surname_MOSKOWITZ_MOSKOVITZ_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Moskowitz", "Moskovitz"));
+    }
+
+    @Test
+    public final void testCompare_Surname_OSULLIVAN_OSUILLEABHAIN_SuccessfulMatch() {
+        assertTrue(getStringEncoder().isEncodeEquals("O'Sullivan", "Ó ' Súilleabháin"));
+    }
+
+    @Test
+    public final void testCompare_Surname_PRZEMYSL_PSHEMESHIL_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals(" P rz e m y s l", " P sh e m e sh i l"));
+    }
+
+    @Test
+    public final void testCompare_Surname_ROSOCHOWACIEC_ROSOKHOVATSETS_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("R o s o ch o w a c ie c", " R o s o k ho v a ts e ts"));
+    }
+
+    @Test
+    public final void testCompare_Surname_SZLAMAWICZ_SHLAMOVITZ_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("SZLAMAWICZ", "SHLAMOVITZ"));
+    }
+
+    @Test
+    public final void testCompare_SurnameCornerCase_Nulls_NoMatch() {
+        assertFalse(getStringEncoder().isEncodeEquals(null, null));
+    }
+
+    @Test
+    public final void testCompare_Surnames_MURPHY_LYNCH_NoMatchExpected() {
+        assertFalse(getStringEncoder().isEncodeEquals("Murphy", "Lynch"));
+    }
+
+    @Test
+    public final void testCompare_SurnamesCornerCase_MURPHY_NoSpace_NoMatch() {
+        assertFalse(getStringEncoder().isEncodeEquals("Murphy", ""));
+    }
+
+    @Test
+    public final void testCompare_SurnamesCornerCase_MURPHY_Space_NoMatch() {
+        assertFalse(getStringEncoder().isEncodeEquals("Murphy", " "));
+    }
+
+    @Test
+    public final void testCompare_TOMASZ_TOM_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Tomasz", "tom"));
+    }
+
+    @Test
+    public final void testCompare_ZACH_ZAKARIA_SuccessfullyMatched() {
+        assertTrue(getStringEncoder().isEncodeEquals("Zach", "Zacharia"));
     }
 
     @Test
@@ -297,226 +300,222 @@ public class MatchRatingApproachEncoderTest extends StringEncoderAbstractTest<Ma
         assertTrue(getStringEncoder().isEncodeEquals("John", "John"));
     }
 
-    // ***** END REGION - TEST GET MRA ENCODING
-
-    // ***** BEGIN REGION - TEST GET MRA COMPARISONS
-
-    @Test
-    public final void testCompare_SMITH_SMYTH_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("smith", "smyth"));
-    }
-
-    @Test
-    public final void testCompare_BURNS_BOURNE_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Burns", "Bourne"));
-    }
-
-    @Test
-    public final void testCompare_ShortNames_AL_ED_WorksButNoMatch() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("Al", "Ed"));
-    }
-
-    @Test
-    public final void testCompare_CATHERINE_KATHRYN_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Catherine", "Kathryn"));
-    }
-
-    @Test
-    public final void testCompare_BRIAN_BRYAN_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Brian", "Bryan"));
-    }
-
-    @Test
-    public final void testCompare_SEAN_SHAUN_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Séan", "Shaun"));
-    }
-
-    @Test
-    public final void testCompare_COLM_COLIN_WithAccentsAndSymbolsAndSpaces_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Cólm.   ", "C-olín"));
-    }
-
-    @Test
-    public final void testCompare_STEPHEN_STEVEN_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Stephen", "Steven"));
-    }
-
-    @Test
-    public final void testCompare_STEVEN_STEFAN_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Steven", "Stefan"));
-    }
-
-    @Test
-    public final void testCompare_STEPHEN_STEFAN_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Stephen", "Stefan"));
-    }
-
-    @Test
-    public final void testCompare_SAM_SAMUEL_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Sam", "Samuel"));
-    }
-
-    @Test
-    public final void testCompare_MICKY_MICHAEL_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Micky", "Michael"));
-    }
-
-    @Test
-    public final void testCompare_OONA_OONAGH_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Oona", "Oonagh"));
-    }
-
-    @Test
-    public final void testCompare_SOPHIE_SOFIA_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Sophie", "Sofia"));
-    }
-
-    @Test
-    public final void testCompare_FRANCISZEK_FRANCES_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Franciszek", "Frances"));
-    }
-
-    @Test
-    public final void testCompare_TOMASZ_TOM_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Tomasz", "tom"));
-    }
-
-    @Test
-    public final void testCompare_SmallInput_CARK_Kl_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Kl", "Karl"));
-    }
-
     @Test
     public final void testCompareNameToSingleLetter_KARL_C_DoesNotMatch() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("Karl", "C"));
+        assertFalse(getStringEncoder().isEncodeEquals("Karl", "C"));
     }
 
     @Test
-    public final void testCompare_ZACH_ZAKARIA_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Zach", "Zacharia"));
+    public final void testGetEncoding_HARPER_HRPR() {
+        assertEquals("HRPR", getStringEncoder().encode("HARPER"));
     }
 
     @Test
-    public final void testCompare_KARL_ALESSANDRO_DoesNotMatch() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("Karl", "Alessandro"));
+    public final void testGetEncoding_NoSpace_to_Nothing() {
+        assertEquals("", getStringEncoder().encode(""));
     }
 
     @Test
-    public final void testCompare_Forenames_UNA_OONAGH_ShouldSuccessfullyMatchButDoesNot() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("Úna", "Oonagh")); // Disappointing
+    public final void testGetEncoding_Null_to_Nothing() {
+        assertEquals("", getStringEncoder().encode(null));
+    }
+
+    @Test
+    public final void testGetEncoding_One_Letter_to_Nothing() {
+        assertEquals("", getStringEncoder().encode("E"));
+    }
+
+    @Test
+    public final void testGetEncoding_SMITH_to_SMTH() {
+        assertEquals("SMTH", getStringEncoder().encode("Smith"));
+    }
+
+    @Test
+    public final void testGetEncoding_SMYTH_to_SMYTH() {
+        assertEquals("SMYTH", getStringEncoder().encode("Smyth"));
+    }
+
+    @Test
+    public final void testGetEncoding_Space_to_Nothing() {
+        assertEquals("", getStringEncoder().encode(" "));
+    }
+
+    @Test
+    public final void testGetFirstLast3__ALEXANDER_Returns_Aleder() {
+        assertEquals("Aleder", getStringEncoder().getFirst3Last3("Alexzander"));
+    }
+
+    @Test
+    public final void testGetFirstLast3_PETE_Returns_PETE() {
+        assertEquals("PETE", getStringEncoder().getFirst3Last3("PETE"));
+    }
+
+    @Test
+    public final void testGetMinRating_1_Returns5_Successfully() {
+        assertEquals(5, getStringEncoder().getMinRating(1));
+    }
+
+    @Test
+    public final void testgetMinRating_10_Returns3_Successfully() {
+        assertEquals(3, getStringEncoder().getMinRating(10));
+    }
+
+    @Test
+    public final void testgetMinRating_11_Returns_3_Successfully() {
+        assertEquals(3, getStringEncoder().getMinRating(11));
+    }
+
+    @Test
+    public final void testGetMinRating_13_Returns_1_Successfully() {
+        assertEquals(1, getStringEncoder().getMinRating(13));
+    }
+
+    @Test
+    public final void testGetMinRating_2_Returns5_Successfully() {
+        assertEquals(5, getStringEncoder().getMinRating(2));
+    }
+
+    @Test
+    public final void testgetMinRating_5_Returns4_Successfully() {
+        assertEquals(4, getStringEncoder().getMinRating(5));
+    }
+
+    @Test
+    public final void testgetMinRating_5_Returns4_Successfully2() {
+        assertEquals(4, getStringEncoder().getMinRating(5));
+    }
+
+    @Test
+    public final void testgetMinRating_6_Returns4_Successfully() {
+        assertEquals(4, getStringEncoder().getMinRating(6));
+    }
+
+    @Test
+    public final void testGetMinRating_7_Return4_Successfully() {
+        assertEquals(4, getStringEncoder().getMinRating(7));
     }
 
     // ***** Begin Region - Test Get Encoding - Surnames
 
     @Test
-    public final void testCompare_Surname_OSULLIVAN_OSUILLEABHAIN_SuccessfulMatch() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("O'Sullivan", "Ó ' Súilleabháin"));
+    public final void testgetMinRating_7_Returns4_Successfully() {
+        assertEquals(4, getStringEncoder().getMinRating(7));
     }
 
     @Test
-    public final void testCompare_LongSurnames_MORIARTY_OMUIRCHEARTAIGH_DoesNotSuccessfulMatch() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("Moriarty", "OMuircheartaigh"));
+    public final void testgetMinRating_8_Returns3_Successfully() {
+        assertEquals(3, getStringEncoder().getMinRating(8));
     }
 
     @Test
-    public final void testCompare_LongSurnames_OMUIRCHEARTAIGH_OMIREADHAIGH_SuccessfulMatch() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("o'muireadhaigh", "Ó 'Muircheartaigh "));
+    public final void testIsEncodeEquals_CornerCase_FirstNameJust1Letter_ReturnsFalse() {
+        assertFalse(getStringEncoder().isEncodeEquals("t", "test"));
     }
 
     @Test
-    public final void testCompare_Surname_COOPERFLYNN_SUPERLYN_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Cooper-Flynn", "Super-Lyn"));
+    public final void testIsEncodeEquals_CornerCase_FirstNameJustSpace_ReturnsFalse() {
+        assertFalse(getStringEncoder().isEncodeEquals(" ", "test"));
     }
 
     @Test
-    public final void testCompare_Surname_HAILEY_HALLEY_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Hailey", "Halley"));
-    }
-
-    // **** BEGIN YIDDISH/SLAVIC SECTION ****
-
-    @Test
-    public final void testCompare_Surname_AUERBACH_UHRBACH_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Auerbach", "Uhrbach"));
+    public final void testIsEncodeEquals_CornerCase_FirstNameNothing_ReturnsFalse() {
+        assertFalse(getStringEncoder().isEncodeEquals("", "test"));
     }
 
     @Test
-    public final void testCompare_Surname_MOSKOWITZ_MOSKOVITZ_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Moskowitz", "Moskovitz"));
+    public final void testIsEncodeEquals_CornerCase_FirstNameNull_ReturnsFalse() {
+        assertFalse(getStringEncoder().isEncodeEquals(null, "test"));
     }
 
     @Test
-    public final void testCompare_Surname_LIPSHITZ_LIPPSZYC_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("LIPSHITZ", "LIPPSZYC"));
+    public final void testIsEncodeEquals_CornerCase_SecondNameJustSpace_ReturnsFalse() {
+        assertFalse(getStringEncoder().isEncodeEquals("test", " "));
     }
 
     @Test
-    public final void testCompare_Surname_LEWINSKY_LEVINSKI_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("LEWINSKY", "LEVINSKI"));
+    public final void testIsEncodeEquals_CornerCase_SecondNameNothing_ReturnsFalse() {
+        assertFalse(getStringEncoder().isEncodeEquals("test", ""));
     }
 
     @Test
-    public final void testCompare_Surname_SZLAMAWICZ_SHLAMOVITZ_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("SZLAMAWICZ", "SHLAMOVITZ"));
+    public final void testIsEncodeEquals_CornerCase_SecondNameNull_ReturnsFalse() {
+        assertFalse(getStringEncoder().isEncodeEquals("test", null));
     }
 
     @Test
-    public final void testCompare_Surname_ROSOCHOWACIEC_ROSOKHOVATSETS_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("R o s o ch o w a c ie c", " R o s o k ho v a ts e ts"));
+    public final void testIsEncodeEqualsSecondNameJust1Letter_ReturnsFalse() {
+        assertFalse(getStringEncoder().isEncodeEquals("test", "t"));
     }
 
     @Test
-    public final void testCompare_Surname_PRZEMYSL_PSHEMESHIL_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals(" P rz e m y s l", " P sh e m e sh i l"));
-    }
-
-    // **** END YIDDISH/SLAVIC SECTION ****
-
-    @Test
-    public final void testCompare_PETERSON_PETERS_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Peterson", "Peters"));
+    public final void testIsVowel_CapitalA_ReturnsTrue() {
+        assertTrue(getStringEncoder().isVowel("A"));
     }
 
     @Test
-    public final void testCompare_MCGOWAN_MCGEOGHEGAN_SuccessfullyMatched() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("McGowan", "Mc Geoghegan"));
+    public final void testIsVowel_SingleVowel_ReturnsTrue() {
+        assertTrue(getStringEncoder().isVowel("I"));
     }
 
     @Test
-    public final void testCompare_SurnamesCornerCase_MURPHY_Space_NoMatch() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("Murphy", " "));
+    public final void testIsVowel_SmallD_ReturnsFalse() {
+        assertFalse(getStringEncoder().isVowel("d"));
     }
 
     @Test
-    public final void testCompare_SurnamesCornerCase_MURPHY_NoSpace_NoMatch() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("Murphy", ""));
+    public final void testLeftToRightThenRightToLeft_ALEXANDER_ALEXANDRA_Returns4() {
+        assertEquals(4, getStringEncoder().leftToRightThenRightToLeftProcessing("ALEXANDER", "ALEXANDRA"));
     }
 
     @Test
-    public final void testCompare_SurnameCornerCase_Nulls_NoMatch() {
-        assertFalse(this.getStringEncoder().isEncodeEquals(null, null));
+    public final void testLeftToRightThenRightToLeft_EINSTEIN_MICHAELA_Returns0() {
+        assertEquals(0, getStringEncoder().leftToRightThenRightToLeftProcessing("EINSTEIN", "MICHAELA"));
     }
 
     @Test
-    public final void testCompare_Surnames_MURPHY_LYNCH_NoMatchExpected() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("Murphy", "Lynch"));
+    public final void testPunctuationOnly() {
+        assertEquals(getStringEncoder().encode(".,-"), "");
     }
 
     @Test
-    public final void testCompare_Forenames_SEAN_JOHN_MatchExpected() {
-        assertTrue(this.getStringEncoder().isEncodeEquals("Sean", "John"));
+    public final void testRemoveDoubleConsonants_MISSISSIPPI_RemovedSuccessfully() {
+        assertEquals("MISISIPI", getStringEncoder().removeDoubleConsonants("MISSISSIPPI"));
     }
 
     @Test
-    public final void testCompare_Forenames_SEAN_PETE_NoMatchExpected() {
-        assertFalse(this.getStringEncoder().isEncodeEquals("Sean", "Pete"));
+    public final void testRemoveDoubleDoubleVowel_BEETLE_NotRemoved() {
+        assertEquals("BEETLE", getStringEncoder().removeDoubleConsonants("BEETLE"));
     }
 
-    @Override
-    protected MatchRatingApproachEncoder createStringEncoder() {
-        return new MatchRatingApproachEncoder();
+    @Test
+    public final void testRemoveSingleDoubleConsonants_BUBLE_RemovedSuccessfully() {
+        assertEquals("BUBLE", getStringEncoder().removeDoubleConsonants("BUBBLE"));
+    }
+
+    @Test
+    public final void testRemoveVowel__AIDAN_Returns_ADN() {
+        assertEquals("ADN", getStringEncoder().removeVowels("AIDAN"));
+    }
+
+    @Test
+    public final void testRemoveVowel__DECLAN_Returns_DCLN() {
+        assertEquals("DCLN", getStringEncoder().removeVowels("DECLAN"));
     }
 
     // ***** END REGION - TEST GET MRA COMPARISONS
 
+    @Test
+    public final void testRemoveVowel_ALESSANDRA_Returns_ALSSNDR() {
+        assertEquals("ALSSNDR", getStringEncoder().removeVowels("ALESSANDRA"));
+    }
+
+    @Test
+    public final void testVowelAndPunctuationOnly() {
+        assertEquals(getStringEncoder().encode("uoiea.,-AEIOU"), "U");
+    }
+
+    @Test
+    public final void testVowelOnly() {
+        assertEquals(getStringEncoder().encode("aeiouAEIOU"), "A");
+    }
 }
