@@ -20,6 +20,8 @@ package org.apache.commons.codec.net;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 
+import java.nio.charset.StandardCharsets;
+
 import org.apache.commons.codec.CharEncoding;
 import org.apache.commons.codec.DecoderException;
 import org.junit.jupiter.api.Test;
@@ -31,6 +33,10 @@ public class RFC1522CodecTest {
 
     static class RFC1522TestCodec extends RFC1522Codec {
 
+        RFC1522TestCodec() {
+            super(StandardCharsets.UTF_8);
+        }
+
         @Override
         protected byte[] doDecoding(final byte[] bytes) {
             return bytes;
@@ -48,13 +54,6 @@ public class RFC1522CodecTest {
 
     }
 
-    @Test
-    public void testNullInput() throws Exception {
-        final RFC1522TestCodec testCodec = new RFC1522TestCodec();
-        assertNull(testCodec.decodeText(null));
-        assertNull(testCodec.encodeText(null, CharEncoding.UTF_8));
-    }
-
     private void assertExpectedDecoderException(final String s) {
         assertThrows(DecoderException.class, () -> new RFC1522TestCodec().decodeText(s));
     }
@@ -75,4 +74,11 @@ public class RFC1522CodecTest {
         assertExpectedDecoderException("=?UTF-8?W?stuff?=");
     }
 
+    @Test
+    public void testNullInput() throws Exception {
+        final RFC1522TestCodec testCodec = new RFC1522TestCodec();
+        assertNull(testCodec.decodeText(null));
+        assertNull(testCodec.encodeText(null, CharEncoding.UTF_8));
+    }
+
 }
